/*
* This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
*
* Copyright(c) Frederic Siepmann
* http://opensource.cit-ec.de/projects/bonsai
*
* This file may be licensed under the terms of of the
* GNU Lesser General Public License Version 3 (the ``LGPL''),
* or (at your option) any later version.
*
* Software distributed under the License is distributed
* on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
* express or implied. See the LGPL for the specific language
* governing rights and limitations.
*
* You should have received a copy of the LGPL along with this
* program. If not, go to http://www.gnu.org/licenses/lgpl.html
* or write to the Free Software Foundation, Inc.,
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*
* The development of this software was supported by the
* Excellence Cluster EXC 277 Cognitive Interaction Technology.
* The Excellence Cluster EXC 277 is a grant of the Deutsche
* Forschungsgemeinschaft (DFG) in the context of the German
* Excellence Initiative.
*
* Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
*               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
*               Marian Pohling, Lukas Twardon, Lukas Kettenbach
*/
package de.unibi.airobots.bonsai.actuators;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.btl.data.annotation.MapAnnotation;

/**
 * An interface for Actuators that publish MapAnnotations
 * 
 * @author vrichter
 */
public interface MapAnnotationActuator extends Actuator {

	/**
	 * Creates and publishes a representation of a MapAnnotation.
	 * 
	 * @param annotation
	 *            This MapAnnotation will be published.
	 */
	public void publish(MapAnnotation annotation);

	/**
	 * After a MapAnnotation was published, this method should be used to update
	 * it. When no MapAnnotation was published before this method throws an
	 * Exception.
	 * 
	 * @param newAnnotation
	 * @throws NoDocumentInsertedException
	 */
	public void update(MapAnnotation newAnnotation)
			throws NoMapAnnotationPublishedException;

	/**
	 * An Exception that is thrown when update is called before a MapAnnotation
	 * was published through the insert-method.
	 * 
	 * @author vrichter
	 * 
	 */
	public class NoMapAnnotationPublishedException extends Exception {

		private static final long serialVersionUID = 1L;

		public NoMapAnnotationPublishedException() {
			super("There is no published MapAnnotation,"
					+ " thus it can not be updated.");
		}

	}
}
