/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.examples;

import java.net.URL;

import org.apache.log4j.BasicConfigurator;

import de.unibi.airobots.bonsai.core.BonsaiManager;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.core.SensorListener;
import de.unibi.airobots.bonsai.xcf.sensors.XcfBtlPublisherSensor;
import de.unibi.airobots.btl.data.vision1d.LaserData;

/**
 * Test program for the {@link XcfBtlPublisherSensor} and its reconnection
 * capabilities.
 * 
 * @author jwienke
 */
public class SimpleXcfSensorTest {

    /**
     * Main method.
     * 
     * @param args
     *            command line arguments
     * @throws Exception
     *             error
     */
    public static void main(String[] args) throws Exception {

        BasicConfigurator.configure();

        try {

            URL configUrl = SimpleXcfSensorTest.class.getResource("loader.xml");
            if (configUrl == null) {
                System.err.println("Config not found.");
                System.exit(1);
            }

            BonsaiManager.getInstance().configure(configUrl.toURI());

            System.out.println("Can create laser data subscriber: "
                    + BonsaiManager.getInstance().canCreateSensor(
                            "LaserSensor", LaserData.class));

            Sensor<LaserData> laserSensor = BonsaiManager.getInstance()
                    .createSensor("LaserSensor", LaserData.class);

            laserSensor.addSensorListener(new SensorListener<LaserData>() {

                @Override
                public void newDataAvailable(LaserData newData) {
                    System.out.println("Async: " + newData);
                }

            });

            while (true) {
                // System.out.println(laserSensor.readLast());
                // CHECKSTYLE:OFF
                Thread.sleep(500);
                // CHECKSTYLE:ON
            }

            // CHECKSTYLE:OFF
        } catch (Exception e) {
            // CHECKSTYLE:ON
            e.printStackTrace();
            System.exit(1);
        }

    }
}
