/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.skills.view;

import java.awt.Dimension;
import java.awt.FlowLayout;
import javax.swing.BorderFactory;
import javax.swing.DefaultListModel;
import javax.swing.JList;
import javax.swing.JPanel;

/**
 * Panel that shows the current state and all possible next ones.
 * 
 * @author lkettenb
 */
public class CurrentAndNextStatePanel extends JPanel {
    /*
     * Width and length of the sub panels.
     */
    private static final int SUB_X = 250;
    private static final int SUB_Y = 300;
    
    /**
     * Visible row count of JList.
     */
    private static final int VISIBLE_ROW_COUNT = 20;
    
    /*
     * JLists used by this panel.
     */
    private JList lStates = new JList();
    private JList lNextStates = new JList();
    
    /**
     * DefaultListModels to control current and next states.
     */
    private DefaultListModel lCurrentStatesModel = new DefaultListModel();
    private DefaultListModel lNextStatesModel = new DefaultListModel();

    
    /**
     * Convenience constructor.
     */
    public CurrentAndNextStatePanel() {
        super();
        init();
    }
    
    /**
     * Initializes everything.
     */
    private void init() {
        setLayout(new FlowLayout());
        
        JPanel subPanel = new JPanel();
        subPanel.setBorder(BorderFactory.createTitledBorder(" Current State "));
        lStates.setVisibleRowCount(VISIBLE_ROW_COUNT);
        lStates.setPreferredSize(new Dimension(SUB_X, SUB_Y));
        lStates.setModel(lCurrentStatesModel);
        subPanel.add(lStates);
        add(subPanel);
        
        subPanel = new JPanel();
        subPanel.setBorder(BorderFactory.createTitledBorder(" Next States "));
        lNextStates.setVisibleRowCount(VISIBLE_ROW_COUNT);
        lNextStates.setPreferredSize(new Dimension(SUB_X, SUB_Y));
        lNextStates.setModel(lNextStatesModel);
        subPanel.add(lNextStates);
        add(subPanel);
    }
    
    
    /**
     * Add a current active state to the list.
     * 
     * @param state ID of a current active state.
     */
    public void addCurrentActiveState(String state) {
        lCurrentStatesModel.addElement(state);
    }
    
    
    /**
     * Clear list of current active states.
     * 
     * @param state ID of a current active state.
     */
    public void removeCurrentActiveState(String state) {
        lCurrentStatesModel.removeElement(state);
    }
    
    /**
     * Update the next states list.
     * 
     * @param states List with all states.
     */
    public void updateNextStatesList(String[] states) {
        lNextStatesModel.clear();
        for (String state : states) {
            lNextStatesModel.addElement(state);
        }
    }
}
