/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.xcf;

import net.sf.xcf.ActiveMemory;

/**
 * Interface for classes that work on {@link ActiveMemory}s with the ability to
 * switch the active memory instance while working. This may be the case if that
 * memory dies and is recreated afterwards.
 * 
 * 
 * @author jwienke
 */
public interface ActiveMemoryReconnectable {

    /**
     * Returns the name of the active memory this class needs to work on.
     * 
     * @return active memory name
     */
    String getActiveMemoryName();

    /**
     * Resets the active memory or initializes it.
     * 
     * @param activeMemory
     *            new active memory instance to use
     */
    void resetActiveMemory(ActiveMemory activeMemory);

}
