/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.xcf.configuration;

import de.unibi.airobots.bonsai.core.Actuator;
import de.unibi.airobots.bonsai.core.CoreObjectFactory.ActuatorToConfigure;
import de.unibi.airobots.bonsai.xcf.actuators.XcfNavigationActuator;

/**
 * Configuration for {@link XcfNavigationActuator}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@link ConfiguredXcfActuator#OPTION_SERVER_NAME} (required): name of the
 * server used to control the navigation</li>
 * </ul>
 * 
 * @author jwienke
 */
public class ConfiguredXcfNavigationActuator extends ConfiguredXcfActuator {

    /**
     * Checks if the actuator that can be produced is suitable for the requested
     * configuration.
     * 
     * @param actuatorToConfigure
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(ActuatorToConfigure actuatorToConfigure) {
        return actuatorToConfigure.getActuatorClass().equals(
                XcfNavigationActuator.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Actuator createInstance() {
        return new XcfNavigationActuator(getServerName());
    }

}
