/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.xcf.configuration;

import de.unibi.airobots.bonsai.core.CoreObjectFactory.SensorToConfigure;
import de.unibi.airobots.bonsai.core.Sensor;
import de.unibi.airobots.bonsai.xcf.sensors.XcfRobotStateSensor;
import de.unibi.airobots.btl.data.status.RobotState;
import java.util.Map;

/**
 * Configuration for {@link XcfRobotStateSensor}.
 * <p>
 * Available options:
 * <ul>
 * <li>{@value #OPTION_MEMORY_NAME} (required): Name of the active memory that
 * contains the person information</li>
 * </ul>
 * 
 * @author ltwardon
 */
public class ConfiguredXcfRobotStateSensor extends
        ConfiguredXcfSensor<RobotState> {

    private String memoryName = "";

    /**
     * Name of the user option to specify the active memory
     */
    public static final String OPTION_MEMORY_NAME = "memoryName";

    /**
     * {@inheritDoc}
     */
    @Override
    public void parseOptions(Map<String, String> options)
            throws IllegalArgumentException {

        if (!options.containsKey(OPTION_MEMORY_NAME)) {
            throw new IllegalArgumentException(
                    "Memory name missing with option " + OPTION_MEMORY_NAME);
        }

        memoryName = options.get(OPTION_MEMORY_NAME);

    }

    /**
     * {@inheritDoc}
     */
    @Override
    public Sensor<RobotState> createInstance() {
        return new XcfRobotStateSensor(memoryName);
    }

    /**
     * Checks if the sensor that can be produced is suitable for the requested
     * configuration.
     * 
     * @param sensor
     *            requested configuration
     * @return <code>true</code> if suitable
     */
    public static boolean isSuitableFor(SensorToConfigure sensor) {
        return sensor.getSensorClass()
                .equals(XcfRobotStateSensor.class);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getSubscribersToInitialize() {
        return new String[0];
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String[] getActiveMemoriesToInitialize() {
        return new String[] { memoryName };
    }

}
