/*
 * This file is part of Bielefeld Sensor Actuator Interface (BonSAI).
 *
 * Copyright(c) Frederic Siepmann
 * http://opensource.cit-ec.de/projects/bonsai
 *
 * This file may be licensed under the terms of of the
 * GNU Lesser General Public License Version 3 (the ``LGPL''),
 * or (at your option) any later version.
 *
 * Software distributed under the License is distributed
 * on an ``AS IS'' basis, WITHOUT WARRANTY OF ANY KIND, either
 * express or implied. See the LGPL for the specific language
 * governing rights and limitations.
 *
 * You should have received a copy of the LGPL along with this
 * program. If not, go to http://www.gnu.org/licenses/lgpl.html
 * or write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * The development of this software was supported by the
 * Excellence Cluster EXC 277 Cognitive Interaction Technology.
 * The Excellence Cluster EXC 277 is a grant of the Deutsche
 * Forschungsgemeinschaft (DFG) in the context of the German
 * Excellence Initiative.
 *
 * Contributors: Leon Ziegler, Johannes Wienke, Norman Köster, Torben Töniges,
 *               Annika Rothert, Alexander Baumann, Marcel Dulisch, Maikel Linke,
 *               Marian Pohling, Lukas Twardon, Lukas Kettenbach
 */
package de.unibi.airobots.bonsai.util;

import static org.junit.Assert.assertEquals;

import org.junit.Test;

import de.unibi.airobots.btl.data.navigation.PositionData;
import de.unibi.airobots.btl.units.AngleUnit;
import de.unibi.airobots.btl.units.LengthUnit;

/**
 * Test cases for the {@link CoordinateSystemConverter}.
 * 
 * @author lziegler
 */
public class CoordinateSystemConverterTest {

	@Test
	public void testConversion() throws Exception {

		double angle = 0;
		double dist = 1;
		PositionData pos = new PositionData(1, 1, Math.PI, 0, LengthUnit.METER,
				AngleUnit.RADIAN);
		PositionData newPos = CoordinateSystemConverter
				.polar2NavigationGoalData(pos, angle, dist, AngleUnit.RADIAN,
						LengthUnit.METER);

		System.out.println(newPos.getX(LengthUnit.METER) + ":" + newPos.getY(LengthUnit.METER));

		assertEquals(angle,
				CoordinateSystemConverter.positionData2Angle(pos, newPos,AngleUnit.RADIAN),
				0.0001);

	}
}
